@@ -1,45 +1,41 @@
-# -*- coding: utf-8 -*-
-##############################################################################
-#
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+#!/usr/bin/env python
+
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2011 Cédric Krier <cedric.krier@b2ck.com>
+
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                        HEALTH ICU package                             #
+#                   health_icu.py: main module                          #
+#########################################################################
+
 from trytond.model import ModelView, ModelSQL, fields
 from datetime import datetime
-from dateutil.relativedelta import relativedelta
 from trytond.transaction import Transaction
+from trytond.pool import PoolMeta
 from trytond.pyson import Eval, Not, Bool, Equal
-from .exceptions import PatientAlreadyInICU
+from .exceptions import PatientAlreadyInICU, PatientAlreadyOnMV
 from trytond.i18n import gettext
 
 
 __all__ = ['InpatientRegistration', 'InpatientIcu', 'Glasgow', 'ApacheII',
-            'MechanicalVentilation', 'ChestDrainageAssessment',
-            'PatientRounding']
+           'MechanicalVentilation', 'ChestDrainageAssessment',
+           'PatientRounding']
 
 
-class InpatientRegistration(ModelSQL, ModelView):
-    'Patient admission History'
+class InpatientRegistration(metaclass=PoolMeta):
     __name__ = 'gnuhealth.inpatient.registration'
-    icu = fields.Boolean('ICU', help='Shows if patient was admitted to'
+    icu = fields.Boolean(
+        'ICU', help='Shows if patient was admitted to'
         ' the Intensive Care Unit during the hospitalization period')
-    icu_admissions = fields.One2Many('gnuhealth.inpatient.icu',
+    icu_admissions = fields.One2Many(
+        'gnuhealth.inpatient.icu',
         'name', "ICU Admissions")
 
 
@@ -54,13 +50,15 @@ class InpatientIcu(ModelSQL, ModelView):
             end = datetime.now()
         return end.date() - self.icu_admission_date.date()
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code', required=True)
 
     admitted = fields.Boolean('Admitted', help="Will be set when the patient \
         is currently admitted at ICU")
 
-    icu_admission_date = fields.DateTime('ICU Admission',
+    icu_admission_date = fields.DateTime(
+        'ICU Admission',
         help="ICU Admission Date", required=True)
     discharged_from_icu = fields.Boolean('Discharged')
     icu_discharge_date = fields.DateTime('Discharge', states={
@@ -70,7 +68,8 @@ class InpatientIcu(ModelSQL, ModelView):
         depends=['discharged_from_icu'])
     icu_stay = fields.Function(fields.TimeDelta('Duration'), 'icu_duration')
 
-    mv_history = fields.One2Many('gnuhealth.icu.ventilation',
+    mv_history = fields.One2Many(
+        'gnuhealth.icu.ventilation',
         'name', "Mechanical Ventilation History")
 
     @classmethod
@@ -82,11 +81,13 @@ class InpatientIcu(ModelSQL, ModelView):
     def check_patient_admitted_at_icu(self):
         # Verify that the patient is not at ICU already
         cursor = Transaction().connection.cursor()
-        cursor.execute("SELECT count(name) "
-            "FROM " + self._table + "  \
-            WHERE (name = %s AND admitted)",
-            (str(self.name.id),))
-        if cursor.fetchone()[0] > 1:
+        table = self.__class__.__table__()
+        cursor.execute(
+            *table.select(
+                table.name, where=(
+                    (table.name == self.name.id) &
+                    (table.admitted))))
+        if cursor.fetchone():
             raise PatientAlreadyInICU(
                 gettext('health_icu.msg_patient_already_in_icu'))
 
@@ -108,13 +109,16 @@ class Glasgow(ModelSQL, ModelView):
     'Glasgow Coma Scale'
     __name__ = 'gnuhealth.icu.glasgow'
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code', required=True)
 
-    evaluation_date = fields.DateTime('Date', help="Date / Time",
+    evaluation_date = fields.DateTime(
+        'Date', help="Date / Time",
         required=True)
 
-    glasgow = fields.Integer('Glasgow',
+    glasgow = fields.Integer(
+        'Glasgow',
         help='Level of Consciousness - on Glasgow Coma Scale :  < 9 severe -'
         ' 9-12 Moderate, > 13 minor')
     glasgow_eyes = fields.Selection([
@@ -178,9 +182,11 @@ class ApacheII(ModelSQL, ModelView):
     'Apache II scoring'
     __name__ = 'gnuhealth.icu.apache2'
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code', required=True)
-    score_date = fields.DateTime('Date', help="Date of the score",
+    score_date = fields.DateTime(
+        'Date', help="Date of the score",
         required=True)
 
     age = fields.Integer('Age', help='Patient age in years')
@@ -198,12 +204,15 @@ class ApacheII(ModelSQL, ModelView):
     serum_potassium = fields.Float('Potassium')
     serum_creatinine = fields.Float('Creatinine')
     arf = fields.Boolean('ARF', help='Acute Renal Failure')
-    wbc = fields.Float('WBC', help="White blood cells x 1000 - if you"
+    wbc = fields.Float(
+        'WBC', help="White blood cells x 1000 - if you"
         " want to input 4500 wbc / ml, type in 4.5")
     hematocrit = fields.Float('Hematocrit')
-    gcs = fields.Integer('GSC', help='Last Glasgow Coma Scale'
+    gcs = fields.Integer(
+        'GSC', help='Last Glasgow Coma Scale'
         ' You can use the GSC calculator from the Patient Evaluation Form.')
-    chronic_condition = fields.Boolean('Chronic condition',
+    chronic_condition = fields.Boolean(
+        'Chronic condition',
         help='Organ Failure or immunocompromised patient')
     hospital_admission_type = fields.Selection([
         (None, ''),
@@ -215,22 +224,24 @@ class ApacheII(ModelSQL, ModelView):
 
     apache_score = fields.Integer('Score')
 
-    #Default FiO2 PaO2 and PaCO2 so we do the A-a gradient
-    #calculation with non-null values
+    # Default FiO2 PaO2 and PaCO2 so we do the A-a gradient
+    # calculation with non-null values
 
     @fields.depends('fio2', 'pao2', 'paco2')
     def on_change_with_aado2(self):
-    # Calculates the Alveolar-arterial difference
-    # based on FiO2, PaCO2 and PaO2 values
+        # Calculates the Alveolar-arterial difference
+        # based on FiO2, PaCO2 and PaO2 values
+
         if (self.fio2 and self.paco2 and self.pao2):
             return (713 * self.fio2) - (self.paco2 / 0.8) - self.pao2
 
-    @fields.depends('age', 'temperature', 'mean_ap', 'heart_rate',
+    @fields.depends(
+        'age', 'temperature', 'mean_ap', 'heart_rate',
         'respiratory_rate', 'fio2', 'pao2', 'aado2', 'ph', 'serum_sodium',
         'serum_potassium', 'serum_creatinine', 'arf', 'wbc', 'hematocrit',
         'gcs', 'chronic_condition', 'hospital_admission_type')
     def on_change_with_apache_score(self):
-    # Calculate the APACHE SCORE from the variables in the
+        # Calculate the APACHE SCORE from the variables in the
 
         total = 0
         # Age
@@ -247,12 +258,12 @@ class ApacheII(ModelSQL, ModelView):
         # Temperature
         if (self.temperature):
             if ((self.temperature >= 38.5 and self.temperature < 39) or
-                (self.temperature >= 34 and self.temperature < 36)):
-                    total = total + 1
+                    (self.temperature >= 34 and self.temperature < 36)):
+                total = total + 1
             elif (self.temperature >= 32 and self.temperature < 34):
                 total = total + 2
             elif ((self.temperature >= 30 and self.temperature < 32) or
-                (self.temperature >= 39 and self.temperature < 41)):
+                    (self.temperature >= 39 and self.temperature < 41)):
                 total = total + 3
             elif (self.temperature >= 41 or self.temperature < 30):
                 total = total + 4
@@ -260,8 +271,8 @@ class ApacheII(ModelSQL, ModelView):
         # Mean Arterial Pressure (MAP)
         if (self.mean_ap):
             if ((self.mean_ap >= 110 and self.mean_ap < 130) or
-                (self.mean_ap >= 50 and self.mean_ap < 70)):
-                    total = total + 2
+                    (self.mean_ap >= 50 and self.mean_ap < 70)):
+                total = total + 2
             elif (self.mean_ap >= 130 and self.mean_ap < 160):
                 total = total + 3
             elif (self.mean_ap >= 160 or self.mean_ap < 50):
@@ -270,23 +281,24 @@ class ApacheII(ModelSQL, ModelView):
         # Heart Rate
         if (self.heart_rate):
             if ((self.heart_rate >= 55 and self.heart_rate < 70) or
-                (self.heart_rate >= 110 and self.heart_rate < 140)):
-                    total = total + 2
+                    (self.heart_rate >= 110 and self.heart_rate < 140)):
+                total = total + 2
             elif ((self.heart_rate >= 40 and self.heart_rate < 55) or
-                (self.heart_rate >= 140 and self.heart_rate < 180)):
-                    total = total + 3
+                    (self.heart_rate >= 140 and self.heart_rate < 180)):
+                total = total + 3
             elif (self.heart_rate >= 180 or self.heart_rate < 40):
                 total = total + 4
 
         # Respiratory Rate
         if (self.respiratory_rate):
             if ((self.respiratory_rate >= 10 and self.respiratory_rate < 12) or
-                (self.respiratory_rate >= 25 and self.respiratory_rate < 35)):
-                    total = total + 1
+                (self.respiratory_rate >= 25 and
+                    self.respiratory_rate < 35)):
+                total = total + 1
             elif (self.respiratory_rate >= 6 and self.respiratory_rate < 10):
-                    total = total + 2
+                total = total + 2
             elif (self.respiratory_rate >= 35 and self.respiratory_rate < 50):
-                    total = total + 3
+                total = total + 3
             elif (self.respiratory_rate >= 50 or self.respiratory_rate < 6):
                 total = total + 4
 
@@ -318,33 +330,34 @@ class ApacheII(ModelSQL, ModelView):
         # Arterial pH
         if (self.ph):
             if (self.ph >= 7.5 and self.ph < 7.6):
-                    total = total + 1
+                total = total + 1
             elif (self.ph >= 7.25 and self.ph < 7.33):
-                    total = total + 2
+                total = total + 2
             elif ((self.ph >= 7.15 and self.ph < 7.25) or
-                (self.ph >= 7.6 and self.ph < 7.7)):
-                    total = total + 3
+                    (self.ph >= 7.6 and self.ph < 7.7)):
+                total = total + 3
             elif (self.ph >= 7.7 or self.ph < 7.15):
                 total = total + 4
 
         # Serum Sodium
         if (self.serum_sodium):
             if (self.serum_sodium >= 150 and self.serum_sodium < 155):
-                    total = total + 1
+                total = total + 1
             elif ((self.serum_sodium >= 155 and self.serum_sodium < 160) or
-                (self.serum_sodium >= 120 and self.serum_sodium < 130)):
-                    total = total + 2
+                    (self.serum_sodium >= 120 and self.serum_sodium < 130)):
+                total = total + 2
             elif ((self.serum_sodium >= 160 and self.serum_sodium < 180) or
-                (self.serum_sodium >= 111 and self.serum_sodium < 120)):
-                    total = total + 3
+                    (self.serum_sodium >= 111 and self.serum_sodium < 120)):
+                total = total + 3
             elif (self.serum_sodium >= 180 or self.serum_sodium < 111):
                 total = total + 4
 
         # Serum Potassium
         if (self.serum_potassium):
             if ((self.serum_potassium >= 3 and self.serum_potassium < 3.5) or
-                (self.serum_potassium >= 5.5 and self.serum_potassium < 6)):
-                    total = total + 1
+                (self.serum_potassium >= 5.5 and
+                    self.serum_potassium < 6)):
+                total = total + 1
             elif (self.serum_potassium >= 2.5 and self.serum_potassium < 3):
                 total = total + 2
             elif (self.serum_potassium >= 6 and self.serum_potassium < 7):
@@ -356,11 +369,12 @@ class ApacheII(ModelSQL, ModelView):
         if (self.serum_creatinine):
             arf_factor = 1
             if (self.arf):
-            # We multiply by 2 the score if there is concomitant ARF
+                # We multiply by 2 the score if there is concomitant ARF
                 arf_factor = 2
             if ((self.serum_creatinine < 0.6) or
-                (self.serum_creatinine >= 1.5 and self.serum_creatinine < 2)):
-                    total = total + 2 * arf_factor
+                (self.serum_creatinine >= 1.5 and
+                    self.serum_creatinine < 2)):
+                total = total + 2 * arf_factor
             elif (self.serum_creatinine >= 2 and self.serum_creatinine < 3.5):
                 total = total + 3 * arf_factor
             elif (self.serum_creatinine >= 3.5):
@@ -371,8 +385,8 @@ class ApacheII(ModelSQL, ModelView):
             if (self.hematocrit >= 46 and self.hematocrit < 50):
                 total = total + 1
             elif ((self.hematocrit >= 50 and self.hematocrit < 60) or
-                (self.hematocrit >= 20 and self.hematocrit < 30)):
-                    total = total + 2
+                    (self.hematocrit >= 20 and self.hematocrit < 30)):
+                total = total + 2
             elif (self.hematocrit >= 60 or self.hematocrit < 20):
                 total = total + 4
 
@@ -381,8 +395,8 @@ class ApacheII(ModelSQL, ModelView):
             if (self.wbc >= 15 and self.wbc < 20):
                 total = total + 1
             elif ((self.wbc >= 20 and self.wbc < 40) or
-                (self.wbc >= 1 and self.wbc < 3)):
-                    total = total + 2
+                    (self.wbc >= 1 and self.wbc < 3)):
+                total = total + 2
             elif (self.wbc >= 40 or self.wbc < 1):
                 total = total + 4
 
@@ -411,7 +425,8 @@ class MechanicalVentilation(ModelSQL, ModelView):
 
         return end.date() - start.date()
 
-    name = fields.Many2One('gnuhealth.inpatient.icu', 'Patient ICU Admission',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.icu', 'Patient ICU Admission',
         required=True)
 
     ventilation = fields.Selection([
@@ -420,9 +435,10 @@ class MechanicalVentilation(ModelSQL, ModelView):
         ('nppv', 'Non-Invasive Positive Pressure'),
         ('ett', 'ETT'),
         ('tracheostomy', 'Tracheostomy')],
-        'Type', help="NPPV = Non-Invasive Positive "
-            "Pressure Ventilation, BiPAP-CPAP \n"
-            "ETT - Endotracheal Tube", sort=False)
+        'Type',
+        help="NPPV = Non-Invasive Positive "
+        "Pressure Ventilation, BiPAP-CPAP \n"
+        "ETT - Endotracheal Tube", sort=False)
 
     ett_size = fields.Integer('ETT Size', states={
             'invisible': Not(Equal(Eval('ventilation'), 'ett'))})
@@ -430,9 +446,11 @@ class MechanicalVentilation(ModelSQL, ModelView):
     tracheostomy_size = fields.Integer('Tracheostomy size', states={
             'invisible': Not(Equal(Eval('ventilation'), 'tracheostomy'))})
 
-    mv_start = fields.DateTime('From', help="Start of Mechanical Ventilation",
+    mv_start = fields.DateTime(
+        'From', help="Start of Mechanical Ventilation",
         required=True)
-    mv_end = fields.DateTime('To', help="End of Mechanical Ventilation",
+    mv_end = fields.DateTime(
+        'To', help="End of Mechanical Ventilation",
         states={
             'invisible': Bool(Eval('current_mv')),
             'required': Not(Bool(Eval('current_mv'))),
@@ -451,11 +469,12 @@ class MechanicalVentilation(ModelSQL, ModelView):
     def check_patient_current_mv(self):
         # Check for only one current mechanical ventilation on patient
         cursor = Transaction().connection.cursor()
-        cursor.execute("SELECT count(name) "
-            "FROM " + self._table + "  \
-            WHERE (name = %s AND current_mv)",
-            (str(self.name.id),))
-        if cursor.fetchone()[0] > 1:
+        table = self.__class__.__table__()
+        cursor.execute(*table.select(
+                table.name, where=(
+                    (table.name == self.name.id)
+                    & (table.current_mv))))
+        if cursor.fetchone():
             raise PatientAlreadyOnMV(
                 gettext('health_icu.msg_patient_already_on_mv'))
 
@@ -468,7 +487,8 @@ class ChestDrainageAssessment(ModelSQL, ModelView):
     'Chest Drainage Asessment'
     __name__ = 'gnuhealth.icu.chest_drainage'
 
-    name = fields.Many2One('gnuhealth.patient.rounding', 'Rounding',
+    name = fields.Many2One(
+        'gnuhealth.patient.rounding', 'Rounding',
         required=True)
     location = fields.Selection([
         (None, ''),
@@ -495,7 +515,7 @@ class ChestDrainageAssessment(ModelSQL, ModelView):
     remarks = fields.Char('Remarks')
 
 
-class PatientRounding(ModelSQL, ModelView):
+class PatientRounding(metaclass=PoolMeta):
     # Nursing Rounding for ICU
     # Inherit and append to the existing model the new functionality for ICU
 
@@ -503,11 +523,13 @@ class PatientRounding(ModelSQL, ModelView):
 
     STATES = {'readonly': Eval('state') == 'done'}
 
-    icu_patient = fields.Boolean('ICU', help='Check this box if this is'
-    'an Intensive Care Unit rounding.', states=STATES)
+    icu_patient = fields.Boolean(
+        'ICU', help='Check this box if this is'
+        'an Intensive Care Unit rounding.', states=STATES)
     # Neurological assesment
-    gcs = fields.Many2One('gnuhealth.icu.glasgow', 'GCS',
-        domain=[('name', '=', Eval('name'))], depends=['name'],states=STATES)
+    gcs = fields.Many2One(
+        'gnuhealth.icu.glasgow', 'GCS',
+        domain=[('name', '=', Eval('name'))], depends=['name'], states=STATES)
 
     pupil_dilation = fields.Selection([
         ('normal', 'Normal'),
@@ -515,9 +537,11 @@ class PatientRounding(ModelSQL, ModelView):
         ('mydriasis', 'Mydriasis')],
         'Pupil Dilation', sort=False, states=STATES)
 
-    left_pupil = fields.Integer('L', help="size in mm of left pupil",
+    left_pupil = fields.Integer(
+        'L', help="size in mm of left pupil",
         states=STATES)
-    right_pupil = fields.Integer('R', help="size in mm of right pupil",
+    right_pupil = fields.Integer(
+        'R', help="size in mm of right pupil",
         states=STATES)
 
     anisocoria = fields.Boolean('Anisocoria', states=STATES)
@@ -529,7 +553,8 @@ class PatientRounding(ModelSQL, ModelView):
         ('nonreactive', 'Nonreactive')],
         'Pupillary Reactivity', sort=False, states=STATES)
 
-    pupil_consensual_resp = fields.Boolean('Consensual Response',
+    pupil_consensual_resp = fields.Boolean(
+        'Consensual Response',
         help="Pupillary Consensual Response", states=STATES)
 
     # Respiratory assesment
@@ -556,8 +581,9 @@ class PatientRounding(ModelSQL, ModelView):
             },
         depends=['peep'])
 
-    sce = fields.Boolean('SCE', help="Subcutaneous Emphysema",states=STATES)
-    lips_lesion = fields.Boolean('Lips lesion',states=STATES)
+    sce = fields.Boolean(
+        'SCE', help="Subcutaneous Emphysema", states=STATES)
+    lips_lesion = fields.Boolean('Lips lesion', states=STATES)
     oral_mucosa_lesion = fields.Boolean('Oral mucosa lesion', states=STATES)
 
     # Chest expansion characteristics
@@ -566,7 +592,8 @@ class PatientRounding(ModelSQL, ModelView):
         ('symmetric', 'Symmetrical'),
         ('asymmetric', 'Asymmetrical')],
         'Expansion', sort=False, states=STATES)
-    paradoxical_expansion = fields.Boolean('Paradoxical',
+    paradoxical_expansion = fields.Boolean(
+        'Paradoxical',
         help="Paradoxical Chest Expansion", states=STATES)
     tracheal_tug = fields.Boolean('Tracheal Tug', states=STATES)
 
@@ -579,7 +606,8 @@ class PatientRounding(ModelSQL, ModelView):
         'Tracheal alignment', sort=False, states=STATES)
 
     # Chest Drainages
-    chest_drainages = fields.One2Many('gnuhealth.icu.chest_drainage',
+    chest_drainages = fields.One2Many(
+        'gnuhealth.icu.chest_drainage',
         'name', "Drainages", states=STATES)
 
     # Chest X-Ray
@@ -587,9 +615,11 @@ class PatientRounding(ModelSQL, ModelView):
 
     # Cardiovascular assessment
 
-    ecg = fields.Many2One('gnuhealth.patient.ecg', 'Inpatient ECG',
-        domain=[('inpatient_registration_code', '=', Eval('name'))],
-        depends=['name'],states=STATES)
+    ecg = fields.Many2One(
+        'gnuhealth.patient.ecg', 'Inpatient ECG',
+        domain=[
+            ('inpatient_registration_code', '=', Eval('name'))],
+        depends=['name'], states=STATES)
 
     venous_access = fields.Selection([
         (None, ''),
@@ -598,7 +628,8 @@ class PatientRounding(ModelSQL, ModelView):
         ('peripheral', 'Peripheral')],
         'Venous Access', sort=False, states=STATES)
 
-    swan_ganz = fields.Boolean('Swan Ganz',
+    swan_ganz = fields.Boolean(
+        'Swan Ganz',
         help="Pulmonary Artery Catheterization - PAC -", states=STATES)
 
     arterial_access = fields.Boolean('Arterial Access', states=STATES)
@@ -617,11 +648,11 @@ class PatientRounding(ModelSQL, ModelView):
     ssi = fields.Boolean('Surgery Site Infection', states=STATES)
     wound_dehiscence = fields.Boolean('Wound Dehiscence', states=STATES)
     cellulitis = fields.Boolean('Cellulitis', states=STATES)
-    necrotizing_fasciitis = fields.Boolean('Necrotizing fasciitis',
+    necrotizing_fasciitis = fields.Boolean(
+        'Necrotizing fasciitis',
         states=STATES)
 
     # Abdomen & Digestive
-
     vomiting = fields.Selection([
         (None, ''),
         ('none', 'None'),
