@@ -1,32 +1,32 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2022 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#    Copyright (C) 2011 Cédric Krier
 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2011 Cédric Krier <cedric.krier@b2ck.com>
 
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                     HEALTH_ORTHANC package                            #
+#                   setup.py: Setuptools file                           #
+#########################################################################
 from setuptools import setup
 import re
 import os
 import configparser
 
+
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
+    return open(os.path.join(os.path.dirname(__file__), fname),
+                encoding="UTF-8").read()
+
 
 config = configparser.ConfigParser()
-config.read_file(open('tryton.cfg'))
+config.readfp(open('tryton.cfg'))
 info = dict(config.items('tryton'))
 
 for key in ('depends', 'extras_depend', 'xml'):
@@ -34,26 +34,32 @@ for key in ('depends', 'extras_depend', 'xml'):
         info[key] = info[key].strip().splitlines()
 major_version, minor_version = 6, 0
 
-requires = read('requirements.txt').split()
+# Initial packages required specifically for health_orthanc
+requires = ['pendulum', 'beren == 0.7.0']
 
 for dep in info.get('depends', []):
     if (dep == 'health'):
         requires.append('gnuhealth == %s' % (info.get('version')))
 
     elif dep.startswith('health_'):
-        health_package = dep.split('_',1)[1]
-        requires.append('gnuhealth_%s == %s' %
+        health_package = dep.split('_', 1)[1]
+        requires.append(
+            'gnuhealth_%s == %s' %
             (health_package, info.get('version')))
     else:
         if not re.match(r'(ir|res|webdav)(\W|$)', dep):
-            requires.append('trytond_%s >= %s.%s, < %s.%s' %
+            requires.append(
+                'trytond_%s >= %s.%s, < %s.%s' %
                 (dep, major_version, minor_version, major_version,
                     minor_version + 1))
 
-setup(name='gnuhealth_orthanc',
+setup(
+    name='gnuhealth_orthanc',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', 'GNU Health Orthanc package'),
-    long_description=read('README'),
+    description=info.get(
+        'description',
+        'GNU Health Orthanc PACS server integration package'),
+    long_description=read('README.rst'),
     author='GNU Solidario',
     author_email='health@gnusolidario.org',
     url='https://www.gnuhealth.org',
@@ -61,14 +67,15 @@ setup(name='gnuhealth_orthanc',
     package_dir={'trytond.modules.health_orthanc': '.'},
     packages=[
         'trytond.modules.health_orthanc',
+        'trytond.modules.health_orthanc.tests',
         'trytond.modules.health_orthanc.wizard',
         ],
 
     package_data={
-        'trytond.modules.health_orthanc': info.get('xml', []) \
-            + info.get('translation', []) \
-            + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
-               'report/*.fodt', 'icons/*.svg'],
+        'trytond.modules.health_orthanc': info.get('xml', [])
+        + info.get('translation', [])
+        + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
+           'report/*.fodt', 'icons/*.svg'],
         },
 
     classifiers=[
@@ -92,4 +99,7 @@ setup(name='gnuhealth_orthanc',
     [trytond.modules]
     health_orthanc = trytond.modules.health_orthanc
     """,
+    test_suite='tests',
+    test_loader='trytond.test_loader:Loader',
+
     )
